# coding: utf-8

"""
    ORY Hydra

    Welcome to the ORY Hydra HTTP API documentation. You will find documentation for all HTTP APIs here.  # noqa: E501

    The version of the OpenAPI document: v0.0.0-alpha.38
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from ory_hydra_client.configuration import Configuration


class Oauth2TokenResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'access_token': 'str',
        'expires_in': 'int',
        'id_token': 'str',
        'refresh_token': 'str',
        'scope': 'str',
        'token_type': 'str'
    }

    attribute_map = {
        'access_token': 'access_token',
        'expires_in': 'expires_in',
        'id_token': 'id_token',
        'refresh_token': 'refresh_token',
        'scope': 'scope',
        'token_type': 'token_type'
    }

    def __init__(self, access_token=None, expires_in=None, id_token=None, refresh_token=None, scope=None, token_type=None, local_vars_configuration=None):  # noqa: E501
        """Oauth2TokenResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._access_token = None
        self._expires_in = None
        self._id_token = None
        self._refresh_token = None
        self._scope = None
        self._token_type = None
        self.discriminator = None

        if access_token is not None:
            self.access_token = access_token
        if expires_in is not None:
            self.expires_in = expires_in
        if id_token is not None:
            self.id_token = id_token
        if refresh_token is not None:
            self.refresh_token = refresh_token
        if scope is not None:
            self.scope = scope
        if token_type is not None:
            self.token_type = token_type

    @property
    def access_token(self):
        """Gets the access_token of this Oauth2TokenResponse.  # noqa: E501


        :return: The access_token of this Oauth2TokenResponse.  # noqa: E501
        :rtype: str
        """
        return self._access_token

    @access_token.setter
    def access_token(self, access_token):
        """Sets the access_token of this Oauth2TokenResponse.


        :param access_token: The access_token of this Oauth2TokenResponse.  # noqa: E501
        :type: str
        """

        self._access_token = access_token

    @property
    def expires_in(self):
        """Gets the expires_in of this Oauth2TokenResponse.  # noqa: E501


        :return: The expires_in of this Oauth2TokenResponse.  # noqa: E501
        :rtype: int
        """
        return self._expires_in

    @expires_in.setter
    def expires_in(self, expires_in):
        """Sets the expires_in of this Oauth2TokenResponse.


        :param expires_in: The expires_in of this Oauth2TokenResponse.  # noqa: E501
        :type: int
        """

        self._expires_in = expires_in

    @property
    def id_token(self):
        """Gets the id_token of this Oauth2TokenResponse.  # noqa: E501


        :return: The id_token of this Oauth2TokenResponse.  # noqa: E501
        :rtype: str
        """
        return self._id_token

    @id_token.setter
    def id_token(self, id_token):
        """Sets the id_token of this Oauth2TokenResponse.


        :param id_token: The id_token of this Oauth2TokenResponse.  # noqa: E501
        :type: str
        """

        self._id_token = id_token

    @property
    def refresh_token(self):
        """Gets the refresh_token of this Oauth2TokenResponse.  # noqa: E501


        :return: The refresh_token of this Oauth2TokenResponse.  # noqa: E501
        :rtype: str
        """
        return self._refresh_token

    @refresh_token.setter
    def refresh_token(self, refresh_token):
        """Sets the refresh_token of this Oauth2TokenResponse.


        :param refresh_token: The refresh_token of this Oauth2TokenResponse.  # noqa: E501
        :type: str
        """

        self._refresh_token = refresh_token

    @property
    def scope(self):
        """Gets the scope of this Oauth2TokenResponse.  # noqa: E501


        :return: The scope of this Oauth2TokenResponse.  # noqa: E501
        :rtype: str
        """
        return self._scope

    @scope.setter
    def scope(self, scope):
        """Sets the scope of this Oauth2TokenResponse.


        :param scope: The scope of this Oauth2TokenResponse.  # noqa: E501
        :type: str
        """

        self._scope = scope

    @property
    def token_type(self):
        """Gets the token_type of this Oauth2TokenResponse.  # noqa: E501


        :return: The token_type of this Oauth2TokenResponse.  # noqa: E501
        :rtype: str
        """
        return self._token_type

    @token_type.setter
    def token_type(self, token_type):
        """Sets the token_type of this Oauth2TokenResponse.


        :param token_type: The token_type of this Oauth2TokenResponse.  # noqa: E501
        :type: str
        """

        self._token_type = token_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Oauth2TokenResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Oauth2TokenResponse):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    ORY Hydra

    Welcome to the ORY Hydra HTTP API documentation. You will find documentation for all HTTP APIs here.  # noqa: E501

    The version of the OpenAPI document: v0.0.0-alpha.38
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from ory_hydra_client.configuration import Configuration


class OpenIDConnectContext(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'acr_values': 'list[str]',
        'display': 'str',
        'id_token_hint_claims': 'dict(str, object)',
        'login_hint': 'str',
        'ui_locales': 'list[str]'
    }

    attribute_map = {
        'acr_values': 'acr_values',
        'display': 'display',
        'id_token_hint_claims': 'id_token_hint_claims',
        'login_hint': 'login_hint',
        'ui_locales': 'ui_locales'
    }

    def __init__(self, acr_values=None, display=None, id_token_hint_claims=None, login_hint=None, ui_locales=None, local_vars_configuration=None):  # noqa: E501
        """OpenIDConnectContext - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._acr_values = None
        self._display = None
        self._id_token_hint_claims = None
        self._login_hint = None
        self._ui_locales = None
        self.discriminator = None

        if acr_values is not None:
            self.acr_values = acr_values
        if display is not None:
            self.display = display
        if id_token_hint_claims is not None:
            self.id_token_hint_claims = id_token_hint_claims
        if login_hint is not None:
            self.login_hint = login_hint
        if ui_locales is not None:
            self.ui_locales = ui_locales

    @property
    def acr_values(self):
        """Gets the acr_values of this OpenIDConnectContext.  # noqa: E501

        ACRValues is the Authentication AuthorizationContext Class Reference requested in the OAuth 2.0 Authorization request. It is a parameter defined by OpenID Connect and expresses which level of authentication (e.g. 2FA) is required.  OpenID Connect defines it as follows: > Requested Authentication AuthorizationContext Class Reference values. Space-separated string that specifies the acr values that the Authorization Server is being requested to use for processing this Authentication Request, with the values appearing in order of preference. The Authentication AuthorizationContext Class satisfied by the authentication performed is returned as the acr Claim Value, as specified in Section 2. The acr Claim is requested as a Voluntary Claim by this parameter.  # noqa: E501

        :return: The acr_values of this OpenIDConnectContext.  # noqa: E501
        :rtype: list[str]
        """
        return self._acr_values

    @acr_values.setter
    def acr_values(self, acr_values):
        """Sets the acr_values of this OpenIDConnectContext.

        ACRValues is the Authentication AuthorizationContext Class Reference requested in the OAuth 2.0 Authorization request. It is a parameter defined by OpenID Connect and expresses which level of authentication (e.g. 2FA) is required.  OpenID Connect defines it as follows: > Requested Authentication AuthorizationContext Class Reference values. Space-separated string that specifies the acr values that the Authorization Server is being requested to use for processing this Authentication Request, with the values appearing in order of preference. The Authentication AuthorizationContext Class satisfied by the authentication performed is returned as the acr Claim Value, as specified in Section 2. The acr Claim is requested as a Voluntary Claim by this parameter.  # noqa: E501

        :param acr_values: The acr_values of this OpenIDConnectContext.  # noqa: E501
        :type: list[str]
        """

        self._acr_values = acr_values

    @property
    def display(self):
        """Gets the display of this OpenIDConnectContext.  # noqa: E501

        Display is a string value that specifies how the Authorization Server displays the authentication and consent user interface pages to the End-User. The defined values are: page: The Authorization Server SHOULD display the authentication and consent UI consistent with a full User Agent page view. If the display parameter is not specified, this is the default display mode. popup: The Authorization Server SHOULD display the authentication and consent UI consistent with a popup User Agent window. The popup User Agent window should be of an appropriate size for a login-focused dialog and should not obscure the entire window that it is popping up over. touch: The Authorization Server SHOULD display the authentication and consent UI consistent with a device that leverages a touch interface. wap: The Authorization Server SHOULD display the authentication and consent UI consistent with a \"feature phone\" type display.  The Authorization Server MAY also attempt to detect the capabilities of the User Agent and present an appropriate display.  # noqa: E501

        :return: The display of this OpenIDConnectContext.  # noqa: E501
        :rtype: str
        """
        return self._display

    @display.setter
    def display(self, display):
        """Sets the display of this OpenIDConnectContext.

        Display is a string value that specifies how the Authorization Server displays the authentication and consent user interface pages to the End-User. The defined values are: page: The Authorization Server SHOULD display the authentication and consent UI consistent with a full User Agent page view. If the display parameter is not specified, this is the default display mode. popup: The Authorization Server SHOULD display the authentication and consent UI consistent with a popup User Agent window. The popup User Agent window should be of an appropriate size for a login-focused dialog and should not obscure the entire window that it is popping up over. touch: The Authorization Server SHOULD display the authentication and consent UI consistent with a device that leverages a touch interface. wap: The Authorization Server SHOULD display the authentication and consent UI consistent with a \"feature phone\" type display.  The Authorization Server MAY also attempt to detect the capabilities of the User Agent and present an appropriate display.  # noqa: E501

        :param display: The display of this OpenIDConnectContext.  # noqa: E501
        :type: str
        """

        self._display = display

    @property
    def id_token_hint_claims(self):
        """Gets the id_token_hint_claims of this OpenIDConnectContext.  # noqa: E501

        IDTokenHintClaims are the claims of the ID Token previously issued by the Authorization Server being passed as a hint about the End-User's current or past authenticated session with the Client.  # noqa: E501

        :return: The id_token_hint_claims of this OpenIDConnectContext.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._id_token_hint_claims

    @id_token_hint_claims.setter
    def id_token_hint_claims(self, id_token_hint_claims):
        """Sets the id_token_hint_claims of this OpenIDConnectContext.

        IDTokenHintClaims are the claims of the ID Token previously issued by the Authorization Server being passed as a hint about the End-User's current or past authenticated session with the Client.  # noqa: E501

        :param id_token_hint_claims: The id_token_hint_claims of this OpenIDConnectContext.  # noqa: E501
        :type: dict(str, object)
        """

        self._id_token_hint_claims = id_token_hint_claims

    @property
    def login_hint(self):
        """Gets the login_hint of this OpenIDConnectContext.  # noqa: E501

        LoginHint hints about the login identifier the End-User might use to log in (if necessary). This hint can be used by an RP if it first asks the End-User for their e-mail address (or other identifier) and then wants to pass that value as a hint to the discovered authorization service. This value MAY also be a phone number in the format specified for the phone_number Claim. The use of this parameter is optional.  # noqa: E501

        :return: The login_hint of this OpenIDConnectContext.  # noqa: E501
        :rtype: str
        """
        return self._login_hint

    @login_hint.setter
    def login_hint(self, login_hint):
        """Sets the login_hint of this OpenIDConnectContext.

        LoginHint hints about the login identifier the End-User might use to log in (if necessary). This hint can be used by an RP if it first asks the End-User for their e-mail address (or other identifier) and then wants to pass that value as a hint to the discovered authorization service. This value MAY also be a phone number in the format specified for the phone_number Claim. The use of this parameter is optional.  # noqa: E501

        :param login_hint: The login_hint of this OpenIDConnectContext.  # noqa: E501
        :type: str
        """

        self._login_hint = login_hint

    @property
    def ui_locales(self):
        """Gets the ui_locales of this OpenIDConnectContext.  # noqa: E501

        UILocales is the End-User'id preferred languages and scripts for the user interface, represented as a space-separated list of BCP47 [RFC5646] language tag values, ordered by preference. For instance, the value \"fr-CA fr en\" represents a preference for French as spoken in Canada, then French (without a region designation), followed by English (without a region designation). An error SHOULD NOT result if some or all of the requested locales are not supported by the OpenID Provider.  # noqa: E501

        :return: The ui_locales of this OpenIDConnectContext.  # noqa: E501
        :rtype: list[str]
        """
        return self._ui_locales

    @ui_locales.setter
    def ui_locales(self, ui_locales):
        """Sets the ui_locales of this OpenIDConnectContext.

        UILocales is the End-User'id preferred languages and scripts for the user interface, represented as a space-separated list of BCP47 [RFC5646] language tag values, ordered by preference. For instance, the value \"fr-CA fr en\" represents a preference for French as spoken in Canada, then French (without a region designation), followed by English (without a region designation). An error SHOULD NOT result if some or all of the requested locales are not supported by the OpenID Provider.  # noqa: E501

        :param ui_locales: The ui_locales of this OpenIDConnectContext.  # noqa: E501
        :type: list[str]
        """

        self._ui_locales = ui_locales

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OpenIDConnectContext):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OpenIDConnectContext):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    ORY Hydra

    Welcome to the ORY Hydra HTTP API documentation. You will find documentation for all HTTP APIs here.  # noqa: E501

    The version of the OpenAPI document: v0.0.0-alpha.38
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from ory_hydra_client.configuration import Configuration


class OAuth2Client(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'allowed_cors_origins': 'list[str]',
        'audience': 'list[str]',
        'backchannel_logout_session_required': 'bool',
        'backchannel_logout_uri': 'str',
        'client_id': 'str',
        'client_name': 'str',
        'client_secret': 'str',
        'client_secret_expires_at': 'int',
        'client_uri': 'str',
        'contacts': 'list[str]',
        'created_at': 'datetime',
        'frontchannel_logout_session_required': 'bool',
        'frontchannel_logout_uri': 'str',
        'grant_types': 'list[str]',
        'jwks': 'JSONWebKeySet',
        'jwks_uri': 'str',
        'logo_uri': 'str',
        'metadata': 'dict(str, object)',
        'owner': 'str',
        'policy_uri': 'str',
        'post_logout_redirect_uris': 'list[str]',
        'redirect_uris': 'list[str]',
        'request_object_signing_alg': 'str',
        'request_uris': 'list[str]',
        'response_types': 'list[str]',
        'scope': 'str',
        'sector_identifier_uri': 'str',
        'subject_type': 'str',
        'token_endpoint_auth_method': 'str',
        'tos_uri': 'str',
        'updated_at': 'datetime',
        'userinfo_signed_response_alg': 'str'
    }

    attribute_map = {
        'allowed_cors_origins': 'allowed_cors_origins',
        'audience': 'audience',
        'backchannel_logout_session_required': 'backchannel_logout_session_required',
        'backchannel_logout_uri': 'backchannel_logout_uri',
        'client_id': 'client_id',
        'client_name': 'client_name',
        'client_secret': 'client_secret',
        'client_secret_expires_at': 'client_secret_expires_at',
        'client_uri': 'client_uri',
        'contacts': 'contacts',
        'created_at': 'created_at',
        'frontchannel_logout_session_required': 'frontchannel_logout_session_required',
        'frontchannel_logout_uri': 'frontchannel_logout_uri',
        'grant_types': 'grant_types',
        'jwks': 'jwks',
        'jwks_uri': 'jwks_uri',
        'logo_uri': 'logo_uri',
        'metadata': 'metadata',
        'owner': 'owner',
        'policy_uri': 'policy_uri',
        'post_logout_redirect_uris': 'post_logout_redirect_uris',
        'redirect_uris': 'redirect_uris',
        'request_object_signing_alg': 'request_object_signing_alg',
        'request_uris': 'request_uris',
        'response_types': 'response_types',
        'scope': 'scope',
        'sector_identifier_uri': 'sector_identifier_uri',
        'subject_type': 'subject_type',
        'token_endpoint_auth_method': 'token_endpoint_auth_method',
        'tos_uri': 'tos_uri',
        'updated_at': 'updated_at',
        'userinfo_signed_response_alg': 'userinfo_signed_response_alg'
    }

    def __init__(self, allowed_cors_origins=None, audience=None, backchannel_logout_session_required=None, backchannel_logout_uri=None, client_id=None, client_name=None, client_secret=None, client_secret_expires_at=None, client_uri=None, contacts=None, created_at=None, frontchannel_logout_session_required=None, frontchannel_logout_uri=None, grant_types=None, jwks=None, jwks_uri=None, logo_uri=None, metadata=None, owner=None, policy_uri=None, post_logout_redirect_uris=None, redirect_uris=None, request_object_signing_alg=None, request_uris=None, response_types=None, scope=None, sector_identifier_uri=None, subject_type=None, token_endpoint_auth_method=None, tos_uri=None, updated_at=None, userinfo_signed_response_alg=None, local_vars_configuration=None):  # noqa: E501
        """OAuth2Client - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._allowed_cors_origins = None
        self._audience = None
        self._backchannel_logout_session_required = None
        self._backchannel_logout_uri = None
        self._client_id = None
        self._client_name = None
        self._client_secret = None
        self._client_secret_expires_at = None
        self._client_uri = None
        self._contacts = None
        self._created_at = None
        self._frontchannel_logout_session_required = None
        self._frontchannel_logout_uri = None
        self._grant_types = None
        self._jwks = None
        self._jwks_uri = None
        self._logo_uri = None
        self._metadata = None
        self._owner = None
        self._policy_uri = None
        self._post_logout_redirect_uris = None
        self._redirect_uris = None
        self._request_object_signing_alg = None
        self._request_uris = None
        self._response_types = None
        self._scope = None
        self._sector_identifier_uri = None
        self._subject_type = None
        self._token_endpoint_auth_method = None
        self._tos_uri = None
        self._updated_at = None
        self._userinfo_signed_response_alg = None
        self.discriminator = None

        if allowed_cors_origins is not None:
            self.allowed_cors_origins = allowed_cors_origins
        if audience is not None:
            self.audience = audience
        if backchannel_logout_session_required is not None:
            self.backchannel_logout_session_required = backchannel_logout_session_required
        if backchannel_logout_uri is not None:
            self.backchannel_logout_uri = backchannel_logout_uri
        if client_id is not None:
            self.client_id = client_id
        if client_name is not None:
            self.client_name = client_name
        if client_secret is not None:
            self.client_secret = client_secret
        if client_secret_expires_at is not None:
            self.client_secret_expires_at = client_secret_expires_at
        if client_uri is not None:
            self.client_uri = client_uri
        if contacts is not None:
            self.contacts = contacts
        if created_at is not None:
            self.created_at = created_at
        if frontchannel_logout_session_required is not None:
            self.frontchannel_logout_session_required = frontchannel_logout_session_required
        if frontchannel_logout_uri is not None:
            self.frontchannel_logout_uri = frontchannel_logout_uri
        if grant_types is not None:
            self.grant_types = grant_types
        if jwks is not None:
            self.jwks = jwks
        if jwks_uri is not None:
            self.jwks_uri = jwks_uri
        if logo_uri is not None:
            self.logo_uri = logo_uri
        if metadata is not None:
            self.metadata = metadata
        if owner is not None:
            self.owner = owner
        if policy_uri is not None:
            self.policy_uri = policy_uri
        if post_logout_redirect_uris is not None:
            self.post_logout_redirect_uris = post_logout_redirect_uris
        if redirect_uris is not None:
            self.redirect_uris = redirect_uris
        if request_object_signing_alg is not None:
            self.request_object_signing_alg = request_object_signing_alg
        if request_uris is not None:
            self.request_uris = request_uris
        if response_types is not None:
            self.response_types = response_types
        if scope is not None:
            self.scope = scope
        if sector_identifier_uri is not None:
            self.sector_identifier_uri = sector_identifier_uri
        if subject_type is not None:
            self.subject_type = subject_type
        if token_endpoint_auth_method is not None:
            self.token_endpoint_auth_method = token_endpoint_auth_method
        if tos_uri is not None:
            self.tos_uri = tos_uri
        if updated_at is not None:
            self.updated_at = updated_at
        if userinfo_signed_response_alg is not None:
            self.userinfo_signed_response_alg = userinfo_signed_response_alg

    @property
    def allowed_cors_origins(self):
        """Gets the allowed_cors_origins of this OAuth2Client.  # noqa: E501

        AllowedCORSOrigins are one or more URLs (scheme://host[:port]) which are allowed to make CORS requests to the /oauth/token endpoint. If this array is empty, the sever's CORS origin configuration (`CORS_ALLOWED_ORIGINS`) will be used instead. If this array is set, the allowed origins are appended to the server's CORS origin configuration. Be aware that environment variable `CORS_ENABLED` MUST be set to `true` for this to work.  # noqa: E501

        :return: The allowed_cors_origins of this OAuth2Client.  # noqa: E501
        :rtype: list[str]
        """
        return self._allowed_cors_origins

    @allowed_cors_origins.setter
    def allowed_cors_origins(self, allowed_cors_origins):
        """Sets the allowed_cors_origins of this OAuth2Client.

        AllowedCORSOrigins are one or more URLs (scheme://host[:port]) which are allowed to make CORS requests to the /oauth/token endpoint. If this array is empty, the sever's CORS origin configuration (`CORS_ALLOWED_ORIGINS`) will be used instead. If this array is set, the allowed origins are appended to the server's CORS origin configuration. Be aware that environment variable `CORS_ENABLED` MUST be set to `true` for this to work.  # noqa: E501

        :param allowed_cors_origins: The allowed_cors_origins of this OAuth2Client.  # noqa: E501
        :type: list[str]
        """

        self._allowed_cors_origins = allowed_cors_origins

    @property
    def audience(self):
        """Gets the audience of this OAuth2Client.  # noqa: E501

        Audience is a whitelist defining the audiences this client is allowed to request tokens for. An audience limits the applicability of an OAuth 2.0 Access Token to, for example, certain API endpoints. The value is a list of URLs. URLs MUST NOT contain whitespaces.  # noqa: E501

        :return: The audience of this OAuth2Client.  # noqa: E501
        :rtype: list[str]
        """
        return self._audience

    @audience.setter
    def audience(self, audience):
        """Sets the audience of this OAuth2Client.

        Audience is a whitelist defining the audiences this client is allowed to request tokens for. An audience limits the applicability of an OAuth 2.0 Access Token to, for example, certain API endpoints. The value is a list of URLs. URLs MUST NOT contain whitespaces.  # noqa: E501

        :param audience: The audience of this OAuth2Client.  # noqa: E501
        :type: list[str]
        """

        self._audience = audience

    @property
    def backchannel_logout_session_required(self):
        """Gets the backchannel_logout_session_required of this OAuth2Client.  # noqa: E501

        Boolean value specifying whether the RP requires that a sid (session ID) Claim be included in the Logout Token to identify the RP session with the OP when the backchannel_logout_uri is used. If omitted, the default value is false.  # noqa: E501

        :return: The backchannel_logout_session_required of this OAuth2Client.  # noqa: E501
        :rtype: bool
        """
        return self._backchannel_logout_session_required

    @backchannel_logout_session_required.setter
    def backchannel_logout_session_required(self, backchannel_logout_session_required):
        """Sets the backchannel_logout_session_required of this OAuth2Client.

        Boolean value specifying whether the RP requires that a sid (session ID) Claim be included in the Logout Token to identify the RP session with the OP when the backchannel_logout_uri is used. If omitted, the default value is false.  # noqa: E501

        :param backchannel_logout_session_required: The backchannel_logout_session_required of this OAuth2Client.  # noqa: E501
        :type: bool
        """

        self._backchannel_logout_session_required = backchannel_logout_session_required

    @property
    def backchannel_logout_uri(self):
        """Gets the backchannel_logout_uri of this OAuth2Client.  # noqa: E501

        RP URL that will cause the RP to log itself out when sent a Logout Token by the OP.  # noqa: E501

        :return: The backchannel_logout_uri of this OAuth2Client.  # noqa: E501
        :rtype: str
        """
        return self._backchannel_logout_uri

    @backchannel_logout_uri.setter
    def backchannel_logout_uri(self, backchannel_logout_uri):
        """Sets the backchannel_logout_uri of this OAuth2Client.

        RP URL that will cause the RP to log itself out when sent a Logout Token by the OP.  # noqa: E501

        :param backchannel_logout_uri: The backchannel_logout_uri of this OAuth2Client.  # noqa: E501
        :type: str
        """

        self._backchannel_logout_uri = backchannel_logout_uri

    @property
    def client_id(self):
        """Gets the client_id of this OAuth2Client.  # noqa: E501

        ClientID  is the id for this client.  # noqa: E501

        :return: The client_id of this OAuth2Client.  # noqa: E501
        :rtype: str
        """
        return self._client_id

    @client_id.setter
    def client_id(self, client_id):
        """Sets the client_id of this OAuth2Client.

        ClientID  is the id for this client.  # noqa: E501

        :param client_id: The client_id of this OAuth2Client.  # noqa: E501
        :type: str
        """

        self._client_id = client_id

    @property
    def client_name(self):
        """Gets the client_name of this OAuth2Client.  # noqa: E501

        Name is the human-readable string name of the client to be presented to the end-user during authorization.  # noqa: E501

        :return: The client_name of this OAuth2Client.  # noqa: E501
        :rtype: str
        """
        return self._client_name

    @client_name.setter
    def client_name(self, client_name):
        """Sets the client_name of this OAuth2Client.

        Name is the human-readable string name of the client to be presented to the end-user during authorization.  # noqa: E501

        :param client_name: The client_name of this OAuth2Client.  # noqa: E501
        :type: str
        """

        self._client_name = client_name

    @property
    def client_secret(self):
        """Gets the client_secret of this OAuth2Client.  # noqa: E501

        Secret is the client's secret. The secret will be included in the create request as cleartext, and then never again. The secret is stored using BCrypt so it is impossible to recover it. Tell your users that they need to write the secret down as it will not be made available again.  # noqa: E501

        :return: The client_secret of this OAuth2Client.  # noqa: E501
        :rtype: str
        """
        return self._client_secret

    @client_secret.setter
    def client_secret(self, client_secret):
        """Sets the client_secret of this OAuth2Client.

        Secret is the client's secret. The secret will be included in the create request as cleartext, and then never again. The secret is stored using BCrypt so it is impossible to recover it. Tell your users that they need to write the secret down as it will not be made available again.  # noqa: E501

        :param client_secret: The client_secret of this OAuth2Client.  # noqa: E501
        :type: str
        """

        self._client_secret = client_secret

    @property
    def client_secret_expires_at(self):
        """Gets the client_secret_expires_at of this OAuth2Client.  # noqa: E501

        SecretExpiresAt is an integer holding the time at which the client secret will expire or 0 if it will not expire. The time is represented as the number of seconds from 1970-01-01T00:00:00Z as measured in UTC until the date/time of expiration.  This feature is currently not supported and it's value will always be set to 0.  # noqa: E501

        :return: The client_secret_expires_at of this OAuth2Client.  # noqa: E501
        :rtype: int
        """
        return self._client_secret_expires_at

    @client_secret_expires_at.setter
    def client_secret_expires_at(self, client_secret_expires_at):
        """Sets the client_secret_expires_at of this OAuth2Client.

        SecretExpiresAt is an integer holding the time at which the client secret will expire or 0 if it will not expire. The time is represented as the number of seconds from 1970-01-01T00:00:00Z as measured in UTC until the date/time of expiration.  This feature is currently not supported and it's value will always be set to 0.  # noqa: E501

        :param client_secret_expires_at: The client_secret_expires_at of this OAuth2Client.  # noqa: E501
        :type: int
        """

        self._client_secret_expires_at = client_secret_expires_at

    @property
    def client_uri(self):
        """Gets the client_uri of this OAuth2Client.  # noqa: E501

        ClientURI is an URL string of a web page providing information about the client. If present, the server SHOULD display this URL to the end-user in a clickable fashion.  # noqa: E501

        :return: The client_uri of this OAuth2Client.  # noqa: E501
        :rtype: str
        """
        return self._client_uri

    @client_uri.setter
    def client_uri(self, client_uri):
        """Sets the client_uri of this OAuth2Client.

        ClientURI is an URL string of a web page providing information about the client. If present, the server SHOULD display this URL to the end-user in a clickable fashion.  # noqa: E501

        :param client_uri: The client_uri of this OAuth2Client.  # noqa: E501
        :type: str
        """

        self._client_uri = client_uri

    @property
    def contacts(self):
        """Gets the contacts of this OAuth2Client.  # noqa: E501

        Contacts is a array of strings representing ways to contact people responsible for this client, typically email addresses.  # noqa: E501

        :return: The contacts of this OAuth2Client.  # noqa: E501
        :rtype: list[str]
        """
        return self._contacts

    @contacts.setter
    def contacts(self, contacts):
        """Sets the contacts of this OAuth2Client.

        Contacts is a array of strings representing ways to contact people responsible for this client, typically email addresses.  # noqa: E501

        :param contacts: The contacts of this OAuth2Client.  # noqa: E501
        :type: list[str]
        """

        self._contacts = contacts

    @property
    def created_at(self):
        """Gets the created_at of this OAuth2Client.  # noqa: E501

        CreatedAt returns the timestamp of the client's creation.  # noqa: E501

        :return: The created_at of this OAuth2Client.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this OAuth2Client.

        CreatedAt returns the timestamp of the client's creation.  # noqa: E501

        :param created_at: The created_at of this OAuth2Client.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def frontchannel_logout_session_required(self):
        """Gets the frontchannel_logout_session_required of this OAuth2Client.  # noqa: E501

        Boolean value specifying whether the RP requires that iss (issuer) and sid (session ID) query parameters be included to identify the RP session with the OP when the frontchannel_logout_uri is used. If omitted, the default value is false.  # noqa: E501

        :return: The frontchannel_logout_session_required of this OAuth2Client.  # noqa: E501
        :rtype: bool
        """
        return self._frontchannel_logout_session_required

    @frontchannel_logout_session_required.setter
    def frontchannel_logout_session_required(self, frontchannel_logout_session_required):
        """Sets the frontchannel_logout_session_required of this OAuth2Client.

        Boolean value specifying whether the RP requires that iss (issuer) and sid (session ID) query parameters be included to identify the RP session with the OP when the frontchannel_logout_uri is used. If omitted, the default value is false.  # noqa: E501

        :param frontchannel_logout_session_required: The frontchannel_logout_session_required of this OAuth2Client.  # noqa: E501
        :type: bool
        """

        self._frontchannel_logout_session_required = frontchannel_logout_session_required

    @property
    def frontchannel_logout_uri(self):
        """Gets the frontchannel_logout_uri of this OAuth2Client.  # noqa: E501

        RP URL that will cause the RP to log itself out when rendered in an iframe by the OP. An iss (issuer) query parameter and a sid (session ID) query parameter MAY be included by the OP to enable the RP to validate the request and to determine which of the potentially multiple sessions is to be logged out; if either is included, both MUST be.  # noqa: E501

        :return: The frontchannel_logout_uri of this OAuth2Client.  # noqa: E501
        :rtype: str
        """
        return self._frontchannel_logout_uri

    @frontchannel_logout_uri.setter
    def frontchannel_logout_uri(self, frontchannel_logout_uri):
        """Sets the frontchannel_logout_uri of this OAuth2Client.

        RP URL that will cause the RP to log itself out when rendered in an iframe by the OP. An iss (issuer) query parameter and a sid (session ID) query parameter MAY be included by the OP to enable the RP to validate the request and to determine which of the potentially multiple sessions is to be logged out; if either is included, both MUST be.  # noqa: E501

        :param frontchannel_logout_uri: The frontchannel_logout_uri of this OAuth2Client.  # noqa: E501
        :type: str
        """

        self._frontchannel_logout_uri = frontchannel_logout_uri

    @property
    def grant_types(self):
        """Gets the grant_types of this OAuth2Client.  # noqa: E501

        GrantTypes is an array of grant types the client is allowed to use.  # noqa: E501

        :return: The grant_types of this OAuth2Client.  # noqa: E501
        :rtype: list[str]
        """
        return self._grant_types

    @grant_types.setter
    def grant_types(self, grant_types):
        """Sets the grant_types of this OAuth2Client.

        GrantTypes is an array of grant types the client is allowed to use.  # noqa: E501

        :param grant_types: The grant_types of this OAuth2Client.  # noqa: E501
        :type: list[str]
        """

        self._grant_types = grant_types

    @property
    def jwks(self):
        """Gets the jwks of this OAuth2Client.  # noqa: E501


        :return: The jwks of this OAuth2Client.  # noqa: E501
        :rtype: JSONWebKeySet
        """
        return self._jwks

    @jwks.setter
    def jwks(self, jwks):
        """Sets the jwks of this OAuth2Client.


        :param jwks: The jwks of this OAuth2Client.  # noqa: E501
        :type: JSONWebKeySet
        """

        self._jwks = jwks

    @property
    def jwks_uri(self):
        """Gets the jwks_uri of this OAuth2Client.  # noqa: E501

        URL for the Client's JSON Web Key Set [JWK] document. If the Client signs requests to the Server, it contains the signing key(s) the Server uses to validate signatures from the Client. The JWK Set MAY also contain the Client's encryption keys(s), which are used by the Server to encrypt responses to the Client. When both signing and encryption keys are made available, a use (Key Use) parameter value is REQUIRED for all keys in the referenced JWK Set to indicate each key's intended usage. Although some algorithms allow the same key to be used for both signatures and encryption, doing so is NOT RECOMMENDED, as it is less secure. The JWK x5c parameter MAY be used to provide X.509 representations of keys provided. When used, the bare key values MUST still be present and MUST match those in the certificate.  # noqa: E501

        :return: The jwks_uri of this OAuth2Client.  # noqa: E501
        :rtype: str
        """
        return self._jwks_uri

    @jwks_uri.setter
    def jwks_uri(self, jwks_uri):
        """Sets the jwks_uri of this OAuth2Client.

        URL for the Client's JSON Web Key Set [JWK] document. If the Client signs requests to the Server, it contains the signing key(s) the Server uses to validate signatures from the Client. The JWK Set MAY also contain the Client's encryption keys(s), which are used by the Server to encrypt responses to the Client. When both signing and encryption keys are made available, a use (Key Use) parameter value is REQUIRED for all keys in the referenced JWK Set to indicate each key's intended usage. Although some algorithms allow the same key to be used for both signatures and encryption, doing so is NOT RECOMMENDED, as it is less secure. The JWK x5c parameter MAY be used to provide X.509 representations of keys provided. When used, the bare key values MUST still be present and MUST match those in the certificate.  # noqa: E501

        :param jwks_uri: The jwks_uri of this OAuth2Client.  # noqa: E501
        :type: str
        """

        self._jwks_uri = jwks_uri

    @property
    def logo_uri(self):
        """Gets the logo_uri of this OAuth2Client.  # noqa: E501

        LogoURI is an URL string that references a logo for the client.  # noqa: E501

        :return: The logo_uri of this OAuth2Client.  # noqa: E501
        :rtype: str
        """
        return self._logo_uri

    @logo_uri.setter
    def logo_uri(self, logo_uri):
        """Sets the logo_uri of this OAuth2Client.

        LogoURI is an URL string that references a logo for the client.  # noqa: E501

        :param logo_uri: The logo_uri of this OAuth2Client.  # noqa: E501
        :type: str
        """

        self._logo_uri = logo_uri

    @property
    def metadata(self):
        """Gets the metadata of this OAuth2Client.  # noqa: E501

        Metadata is arbitrary data.  # noqa: E501

        :return: The metadata of this OAuth2Client.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """Sets the metadata of this OAuth2Client.

        Metadata is arbitrary data.  # noqa: E501

        :param metadata: The metadata of this OAuth2Client.  # noqa: E501
        :type: dict(str, object)
        """

        self._metadata = metadata

    @property
    def owner(self):
        """Gets the owner of this OAuth2Client.  # noqa: E501

        Owner is a string identifying the owner of the OAuth 2.0 Client.  # noqa: E501

        :return: The owner of this OAuth2Client.  # noqa: E501
        :rtype: str
        """
        return self._owner

    @owner.setter
    def owner(self, owner):
        """Sets the owner of this OAuth2Client.

        Owner is a string identifying the owner of the OAuth 2.0 Client.  # noqa: E501

        :param owner: The owner of this OAuth2Client.  # noqa: E501
        :type: str
        """

        self._owner = owner

    @property
    def policy_uri(self):
        """Gets the policy_uri of this OAuth2Client.  # noqa: E501

        PolicyURI is a URL string that points to a human-readable privacy policy document that describes how the deployment organization collects, uses, retains, and discloses personal data.  # noqa: E501

        :return: The policy_uri of this OAuth2Client.  # noqa: E501
        :rtype: str
        """
        return self._policy_uri

    @policy_uri.setter
    def policy_uri(self, policy_uri):
        """Sets the policy_uri of this OAuth2Client.

        PolicyURI is a URL string that points to a human-readable privacy policy document that describes how the deployment organization collects, uses, retains, and discloses personal data.  # noqa: E501

        :param policy_uri: The policy_uri of this OAuth2Client.  # noqa: E501
        :type: str
        """

        self._policy_uri = policy_uri

    @property
    def post_logout_redirect_uris(self):
        """Gets the post_logout_redirect_uris of this OAuth2Client.  # noqa: E501

        Array of URLs supplied by the RP to which it MAY request that the End-User's User Agent be redirected using the post_logout_redirect_uri parameter after a logout has been performed.  # noqa: E501

        :return: The post_logout_redirect_uris of this OAuth2Client.  # noqa: E501
        :rtype: list[str]
        """
        return self._post_logout_redirect_uris

    @post_logout_redirect_uris.setter
    def post_logout_redirect_uris(self, post_logout_redirect_uris):
        """Sets the post_logout_redirect_uris of this OAuth2Client.

        Array of URLs supplied by the RP to which it MAY request that the End-User's User Agent be redirected using the post_logout_redirect_uri parameter after a logout has been performed.  # noqa: E501

        :param post_logout_redirect_uris: The post_logout_redirect_uris of this OAuth2Client.  # noqa: E501
        :type: list[str]
        """

        self._post_logout_redirect_uris = post_logout_redirect_uris

    @property
    def redirect_uris(self):
        """Gets the redirect_uris of this OAuth2Client.  # noqa: E501

        RedirectURIs is an array of allowed redirect urls for the client, for example http://mydomain/oauth/callback .  # noqa: E501

        :return: The redirect_uris of this OAuth2Client.  # noqa: E501
        :rtype: list[str]
        """
        return self._redirect_uris

    @redirect_uris.setter
    def redirect_uris(self, redirect_uris):
        """Sets the redirect_uris of this OAuth2Client.

        RedirectURIs is an array of allowed redirect urls for the client, for example http://mydomain/oauth/callback .  # noqa: E501

        :param redirect_uris: The redirect_uris of this OAuth2Client.  # noqa: E501
        :type: list[str]
        """

        self._redirect_uris = redirect_uris

    @property
    def request_object_signing_alg(self):
        """Gets the request_object_signing_alg of this OAuth2Client.  # noqa: E501

        JWS [JWS] alg algorithm [JWA] that MUST be used for signing Request Objects sent to the OP. All Request Objects from this Client MUST be rejected, if not signed with this algorithm.  # noqa: E501

        :return: The request_object_signing_alg of this OAuth2Client.  # noqa: E501
        :rtype: str
        """
        return self._request_object_signing_alg

    @request_object_signing_alg.setter
    def request_object_signing_alg(self, request_object_signing_alg):
        """Sets the request_object_signing_alg of this OAuth2Client.

        JWS [JWS] alg algorithm [JWA] that MUST be used for signing Request Objects sent to the OP. All Request Objects from this Client MUST be rejected, if not signed with this algorithm.  # noqa: E501

        :param request_object_signing_alg: The request_object_signing_alg of this OAuth2Client.  # noqa: E501
        :type: str
        """

        self._request_object_signing_alg = request_object_signing_alg

    @property
    def request_uris(self):
        """Gets the request_uris of this OAuth2Client.  # noqa: E501

        Array of request_uri values that are pre-registered by the RP for use at the OP. Servers MAY cache the contents of the files referenced by these URIs and not retrieve them at the time they are used in a request. OPs can require that request_uri values used be pre-registered with the require_request_uri_registration discovery parameter.  # noqa: E501

        :return: The request_uris of this OAuth2Client.  # noqa: E501
        :rtype: list[str]
        """
        return self._request_uris

    @request_uris.setter
    def request_uris(self, request_uris):
        """Sets the request_uris of this OAuth2Client.

        Array of request_uri values that are pre-registered by the RP for use at the OP. Servers MAY cache the contents of the files referenced by these URIs and not retrieve them at the time they are used in a request. OPs can require that request_uri values used be pre-registered with the require_request_uri_registration discovery parameter.  # noqa: E501

        :param request_uris: The request_uris of this OAuth2Client.  # noqa: E501
        :type: list[str]
        """

        self._request_uris = request_uris

    @property
    def response_types(self):
        """Gets the response_types of this OAuth2Client.  # noqa: E501

        ResponseTypes is an array of the OAuth 2.0 response type strings that the client can use at the authorization endpoint.  # noqa: E501

        :return: The response_types of this OAuth2Client.  # noqa: E501
        :rtype: list[str]
        """
        return self._response_types

    @response_types.setter
    def response_types(self, response_types):
        """Sets the response_types of this OAuth2Client.

        ResponseTypes is an array of the OAuth 2.0 response type strings that the client can use at the authorization endpoint.  # noqa: E501

        :param response_types: The response_types of this OAuth2Client.  # noqa: E501
        :type: list[str]
        """

        self._response_types = response_types

    @property
    def scope(self):
        """Gets the scope of this OAuth2Client.  # noqa: E501

        Scope is a string containing a space-separated list of scope values (as described in Section 3.3 of OAuth 2.0 [RFC6749]) that the client can use when requesting access tokens.  # noqa: E501

        :return: The scope of this OAuth2Client.  # noqa: E501
        :rtype: str
        """
        return self._scope

    @scope.setter
    def scope(self, scope):
        """Sets the scope of this OAuth2Client.

        Scope is a string containing a space-separated list of scope values (as described in Section 3.3 of OAuth 2.0 [RFC6749]) that the client can use when requesting access tokens.  # noqa: E501

        :param scope: The scope of this OAuth2Client.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                scope is not None and not re.search(r'([a-zA-Z0-9\.\*]+\s?)+', scope)):  # noqa: E501
            raise ValueError(r"Invalid value for `scope`, must be a follow pattern or equal to `/([a-zA-Z0-9\.\*]+\s?)+/`")  # noqa: E501

        self._scope = scope

    @property
    def sector_identifier_uri(self):
        """Gets the sector_identifier_uri of this OAuth2Client.  # noqa: E501

        URL using the https scheme to be used in calculating Pseudonymous Identifiers by the OP. The URL references a file with a single JSON array of redirect_uri values.  # noqa: E501

        :return: The sector_identifier_uri of this OAuth2Client.  # noqa: E501
        :rtype: str
        """
        return self._sector_identifier_uri

    @sector_identifier_uri.setter
    def sector_identifier_uri(self, sector_identifier_uri):
        """Sets the sector_identifier_uri of this OAuth2Client.

        URL using the https scheme to be used in calculating Pseudonymous Identifiers by the OP. The URL references a file with a single JSON array of redirect_uri values.  # noqa: E501

        :param sector_identifier_uri: The sector_identifier_uri of this OAuth2Client.  # noqa: E501
        :type: str
        """

        self._sector_identifier_uri = sector_identifier_uri

    @property
    def subject_type(self):
        """Gets the subject_type of this OAuth2Client.  # noqa: E501

        SubjectType requested for responses to this Client. The subject_types_supported Discovery parameter contains a list of the supported subject_type values for this server. Valid types include `pairwise` and `public`.  # noqa: E501

        :return: The subject_type of this OAuth2Client.  # noqa: E501
        :rtype: str
        """
        return self._subject_type

    @subject_type.setter
    def subject_type(self, subject_type):
        """Sets the subject_type of this OAuth2Client.

        SubjectType requested for responses to this Client. The subject_types_supported Discovery parameter contains a list of the supported subject_type values for this server. Valid types include `pairwise` and `public`.  # noqa: E501

        :param subject_type: The subject_type of this OAuth2Client.  # noqa: E501
        :type: str
        """

        self._subject_type = subject_type

    @property
    def token_endpoint_auth_method(self):
        """Gets the token_endpoint_auth_method of this OAuth2Client.  # noqa: E501

        Requested Client Authentication method for the Token Endpoint. The options are client_secret_post, client_secret_basic, private_key_jwt, and none.  # noqa: E501

        :return: The token_endpoint_auth_method of this OAuth2Client.  # noqa: E501
        :rtype: str
        """
        return self._token_endpoint_auth_method

    @token_endpoint_auth_method.setter
    def token_endpoint_auth_method(self, token_endpoint_auth_method):
        """Sets the token_endpoint_auth_method of this OAuth2Client.

        Requested Client Authentication method for the Token Endpoint. The options are client_secret_post, client_secret_basic, private_key_jwt, and none.  # noqa: E501

        :param token_endpoint_auth_method: The token_endpoint_auth_method of this OAuth2Client.  # noqa: E501
        :type: str
        """

        self._token_endpoint_auth_method = token_endpoint_auth_method

    @property
    def tos_uri(self):
        """Gets the tos_uri of this OAuth2Client.  # noqa: E501

        TermsOfServiceURI is a URL string that points to a human-readable terms of service document for the client that describes a contractual relationship between the end-user and the client that the end-user accepts when authorizing the client.  # noqa: E501

        :return: The tos_uri of this OAuth2Client.  # noqa: E501
        :rtype: str
        """
        return self._tos_uri

    @tos_uri.setter
    def tos_uri(self, tos_uri):
        """Sets the tos_uri of this OAuth2Client.

        TermsOfServiceURI is a URL string that points to a human-readable terms of service document for the client that describes a contractual relationship between the end-user and the client that the end-user accepts when authorizing the client.  # noqa: E501

        :param tos_uri: The tos_uri of this OAuth2Client.  # noqa: E501
        :type: str
        """

        self._tos_uri = tos_uri

    @property
    def updated_at(self):
        """Gets the updated_at of this OAuth2Client.  # noqa: E501

        UpdatedAt returns the timestamp of the last update.  # noqa: E501

        :return: The updated_at of this OAuth2Client.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this OAuth2Client.

        UpdatedAt returns the timestamp of the last update.  # noqa: E501

        :param updated_at: The updated_at of this OAuth2Client.  # noqa: E501
        :type: datetime
        """

        self._updated_at = updated_at

    @property
    def userinfo_signed_response_alg(self):
        """Gets the userinfo_signed_response_alg of this OAuth2Client.  # noqa: E501

        JWS alg algorithm [JWA] REQUIRED for signing UserInfo Responses. If this is specified, the response will be JWT [JWT] serialized, and signed using JWS. The default, if omitted, is for the UserInfo Response to return the Claims as a UTF-8 encoded JSON object using the application/json content-type.  # noqa: E501

        :return: The userinfo_signed_response_alg of this OAuth2Client.  # noqa: E501
        :rtype: str
        """
        return self._userinfo_signed_response_alg

    @userinfo_signed_response_alg.setter
    def userinfo_signed_response_alg(self, userinfo_signed_response_alg):
        """Sets the userinfo_signed_response_alg of this OAuth2Client.

        JWS alg algorithm [JWA] REQUIRED for signing UserInfo Responses. If this is specified, the response will be JWT [JWT] serialized, and signed using JWS. The default, if omitted, is for the UserInfo Response to return the Claims as a UTF-8 encoded JSON object using the application/json content-type.  # noqa: E501

        :param userinfo_signed_response_alg: The userinfo_signed_response_alg of this OAuth2Client.  # noqa: E501
        :type: str
        """

        self._userinfo_signed_response_alg = userinfo_signed_response_alg

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OAuth2Client):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OAuth2Client):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa

"""
    ORY Hydra

    Welcome to the ORY Hydra HTTP API documentation. You will find documentation for all HTTP APIs here.  # noqa: E501

    The version of the OpenAPI document: v0.0.0-alpha.38
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "v0.0.0-alpha.38"

# import apis into sdk package
from ory_hydra_client.api.admin_api import AdminApi
from ory_hydra_client.api.public_api import PublicApi

# import ApiClient
from ory_hydra_client.api_client import ApiClient
from ory_hydra_client.configuration import Configuration
from ory_hydra_client.exceptions import OpenApiException
from ory_hydra_client.exceptions import ApiTypeError
from ory_hydra_client.exceptions import ApiValueError
from ory_hydra_client.exceptions import ApiKeyError
from ory_hydra_client.exceptions import ApiException
# import models into sdk package
from ory_hydra_client.models.accept_consent_request import AcceptConsentRequest
from ory_hydra_client.models.accept_login_request import AcceptLoginRequest
from ory_hydra_client.models.completed_request import CompletedRequest
from ory_hydra_client.models.consent_request import ConsentRequest
from ory_hydra_client.models.consent_request_session import ConsentRequestSession
from ory_hydra_client.models.flush_inactive_o_auth2_tokens_request import FlushInactiveOAuth2TokensRequest
from ory_hydra_client.models.generic_error import GenericError
from ory_hydra_client.models.health_not_ready_status import HealthNotReadyStatus
from ory_hydra_client.models.health_status import HealthStatus
from ory_hydra_client.models.json_web_key import JSONWebKey
from ory_hydra_client.models.json_web_key_set import JSONWebKeySet
from ory_hydra_client.models.json_web_key_set_generator_request import JsonWebKeySetGeneratorRequest
from ory_hydra_client.models.login_request import LoginRequest
from ory_hydra_client.models.logout_request import LogoutRequest
from ory_hydra_client.models.o_auth2_client import OAuth2Client
from ory_hydra_client.models.o_auth2_token_introspection import OAuth2TokenIntrospection
from ory_hydra_client.models.oauth2_token_response import Oauth2TokenResponse
from ory_hydra_client.models.oauth_token_response import OauthTokenResponse
from ory_hydra_client.models.open_id_connect_context import OpenIDConnectContext
from ory_hydra_client.models.previous_consent_session import PreviousConsentSession
from ory_hydra_client.models.reject_request import RejectRequest
from ory_hydra_client.models.userinfo_response import UserinfoResponse
from ory_hydra_client.models.version import Version
from ory_hydra_client.models.well_known import WellKnown




# coding: utf-8

"""
    ORY Hydra

    Welcome to the ORY Hydra HTTP API documentation. You will find documentation for all HTTP APIs here.  # noqa: E501

    The version of the OpenAPI document: v0.0.0-alpha.38
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from ory_hydra_client.configuration import Configuration


class JSONWebKeySet(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'keys': 'list[JSONWebKey]'
    }

    attribute_map = {
        'keys': 'keys'
    }

    def __init__(self, keys=None, local_vars_configuration=None):  # noqa: E501
        """JSONWebKeySet - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._keys = None
        self.discriminator = None

        if keys is not None:
            self.keys = keys

    @property
    def keys(self):
        """Gets the keys of this JSONWebKeySet.  # noqa: E501

        The value of the \"keys\" parameter is an array of JWK values.  By default, the order of the JWK values within the array does not imply an order of preference among them, although applications of JWK Sets can choose to assign a meaning to the order for their purposes, if desired.  # noqa: E501

        :return: The keys of this JSONWebKeySet.  # noqa: E501
        :rtype: list[JSONWebKey]
        """
        return self._keys

    @keys.setter
    def keys(self, keys):
        """Sets the keys of this JSONWebKeySet.

        The value of the \"keys\" parameter is an array of JWK values.  By default, the order of the JWK values within the array does not imply an order of preference among them, although applications of JWK Sets can choose to assign a meaning to the order for their purposes, if desired.  # noqa: E501

        :param keys: The keys of this JSONWebKeySet.  # noqa: E501
        :type: list[JSONWebKey]
        """

        self._keys = keys

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, JSONWebKeySet):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, JSONWebKeySet):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    ORY Hydra

    Welcome to the ORY Hydra HTTP API documentation. You will find documentation for all HTTP APIs here.  # noqa: E501

    The version of the OpenAPI document: v0.0.0-alpha.38
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from ory_hydra_client.configuration import Configuration


class OauthTokenResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'access_token': 'str',
        'expires_in': 'int',
        'id_token': 'int',
        'refresh_token': 'str',
        'scope': 'int',
        'token_type': 'str'
    }

    attribute_map = {
        'access_token': 'access_token',
        'expires_in': 'expires_in',
        'id_token': 'id_token',
        'refresh_token': 'refresh_token',
        'scope': 'scope',
        'token_type': 'token_type'
    }

    def __init__(self, access_token=None, expires_in=None, id_token=None, refresh_token=None, scope=None, token_type=None, local_vars_configuration=None):  # noqa: E501
        """OauthTokenResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._access_token = None
        self._expires_in = None
        self._id_token = None
        self._refresh_token = None
        self._scope = None
        self._token_type = None
        self.discriminator = None

        if access_token is not None:
            self.access_token = access_token
        if expires_in is not None:
            self.expires_in = expires_in
        if id_token is not None:
            self.id_token = id_token
        if refresh_token is not None:
            self.refresh_token = refresh_token
        if scope is not None:
            self.scope = scope
        if token_type is not None:
            self.token_type = token_type

    @property
    def access_token(self):
        """Gets the access_token of this OauthTokenResponse.  # noqa: E501

        The access token issued by the authorization server.  # noqa: E501

        :return: The access_token of this OauthTokenResponse.  # noqa: E501
        :rtype: str
        """
        return self._access_token

    @access_token.setter
    def access_token(self, access_token):
        """Sets the access_token of this OauthTokenResponse.

        The access token issued by the authorization server.  # noqa: E501

        :param access_token: The access_token of this OauthTokenResponse.  # noqa: E501
        :type: str
        """

        self._access_token = access_token

    @property
    def expires_in(self):
        """Gets the expires_in of this OauthTokenResponse.  # noqa: E501

        The lifetime in seconds of the access token.  For example, the value \"3600\" denotes that the access token will expire in one hour from the time the response was generated.  # noqa: E501

        :return: The expires_in of this OauthTokenResponse.  # noqa: E501
        :rtype: int
        """
        return self._expires_in

    @expires_in.setter
    def expires_in(self, expires_in):
        """Sets the expires_in of this OauthTokenResponse.

        The lifetime in seconds of the access token.  For example, the value \"3600\" denotes that the access token will expire in one hour from the time the response was generated.  # noqa: E501

        :param expires_in: The expires_in of this OauthTokenResponse.  # noqa: E501
        :type: int
        """

        self._expires_in = expires_in

    @property
    def id_token(self):
        """Gets the id_token of this OauthTokenResponse.  # noqa: E501

        To retrieve a refresh token request the id_token scope.  # noqa: E501

        :return: The id_token of this OauthTokenResponse.  # noqa: E501
        :rtype: int
        """
        return self._id_token

    @id_token.setter
    def id_token(self, id_token):
        """Sets the id_token of this OauthTokenResponse.

        To retrieve a refresh token request the id_token scope.  # noqa: E501

        :param id_token: The id_token of this OauthTokenResponse.  # noqa: E501
        :type: int
        """

        self._id_token = id_token

    @property
    def refresh_token(self):
        """Gets the refresh_token of this OauthTokenResponse.  # noqa: E501

        The refresh token, which can be used to obtain new access tokens. To retrieve it add the scope \"offline\" to your access token request.  # noqa: E501

        :return: The refresh_token of this OauthTokenResponse.  # noqa: E501
        :rtype: str
        """
        return self._refresh_token

    @refresh_token.setter
    def refresh_token(self, refresh_token):
        """Sets the refresh_token of this OauthTokenResponse.

        The refresh token, which can be used to obtain new access tokens. To retrieve it add the scope \"offline\" to your access token request.  # noqa: E501

        :param refresh_token: The refresh_token of this OauthTokenResponse.  # noqa: E501
        :type: str
        """

        self._refresh_token = refresh_token

    @property
    def scope(self):
        """Gets the scope of this OauthTokenResponse.  # noqa: E501

        The scope of the access token  # noqa: E501

        :return: The scope of this OauthTokenResponse.  # noqa: E501
        :rtype: int
        """
        return self._scope

    @scope.setter
    def scope(self, scope):
        """Sets the scope of this OauthTokenResponse.

        The scope of the access token  # noqa: E501

        :param scope: The scope of this OauthTokenResponse.  # noqa: E501
        :type: int
        """

        self._scope = scope

    @property
    def token_type(self):
        """Gets the token_type of this OauthTokenResponse.  # noqa: E501

        The type of the token issued  # noqa: E501

        :return: The token_type of this OauthTokenResponse.  # noqa: E501
        :rtype: str
        """
        return self._token_type

    @token_type.setter
    def token_type(self, token_type):
        """Sets the token_type of this OauthTokenResponse.

        The type of the token issued  # noqa: E501

        :param token_type: The token_type of this OauthTokenResponse.  # noqa: E501
        :type: str
        """

        self._token_type = token_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OauthTokenResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OauthTokenResponse):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    ORY Hydra

    Welcome to the ORY Hydra HTTP API documentation. You will find documentation for all HTTP APIs here.  # noqa: E501

    The version of the OpenAPI document: v0.0.0-alpha.1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import ory_hydra_client
from ory_hydra_client.models.o_auth2_token_introspection import OAuth2TokenIntrospection  # noqa: E501
from ory_hydra_client.rest import ApiException


class TestOAuth2TokenIntrospection(unittest.TestCase):
    """OAuth2TokenIntrospection unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testOAuth2TokenIntrospection(self):
        """Test OAuth2TokenIntrospection"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ory_hydra_client.models.o_auth2_token_introspection.OAuth2TokenIntrospection()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ORY Hydra

    Welcome to the ORY Hydra HTTP API documentation. You will find documentation for all HTTP APIs here.  # noqa: E501

    The version of the OpenAPI document: v0.0.0-alpha.38
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from ory_hydra_client.configuration import Configuration


class ConsentRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'acr': 'str',
        'challenge': 'str',
        'client': 'OAuth2Client',
        'context': 'dict(str, object)',
        'login_challenge': 'str',
        'login_session_id': 'str',
        'oidc_context': 'OpenIDConnectContext',
        'request_url': 'str',
        'requested_access_token_audience': 'list[str]',
        'requested_scope': 'list[str]',
        'skip': 'bool',
        'subject': 'str'
    }

    attribute_map = {
        'acr': 'acr',
        'challenge': 'challenge',
        'client': 'client',
        'context': 'context',
        'login_challenge': 'login_challenge',
        'login_session_id': 'login_session_id',
        'oidc_context': 'oidc_context',
        'request_url': 'request_url',
        'requested_access_token_audience': 'requested_access_token_audience',
        'requested_scope': 'requested_scope',
        'skip': 'skip',
        'subject': 'subject'
    }

    def __init__(self, acr=None, challenge=None, client=None, context=None, login_challenge=None, login_session_id=None, oidc_context=None, request_url=None, requested_access_token_audience=None, requested_scope=None, skip=None, subject=None, local_vars_configuration=None):  # noqa: E501
        """ConsentRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._acr = None
        self._challenge = None
        self._client = None
        self._context = None
        self._login_challenge = None
        self._login_session_id = None
        self._oidc_context = None
        self._request_url = None
        self._requested_access_token_audience = None
        self._requested_scope = None
        self._skip = None
        self._subject = None
        self.discriminator = None

        if acr is not None:
            self.acr = acr
        if challenge is not None:
            self.challenge = challenge
        if client is not None:
            self.client = client
        if context is not None:
            self.context = context
        if login_challenge is not None:
            self.login_challenge = login_challenge
        if login_session_id is not None:
            self.login_session_id = login_session_id
        if oidc_context is not None:
            self.oidc_context = oidc_context
        if request_url is not None:
            self.request_url = request_url
        if requested_access_token_audience is not None:
            self.requested_access_token_audience = requested_access_token_audience
        if requested_scope is not None:
            self.requested_scope = requested_scope
        if skip is not None:
            self.skip = skip
        if subject is not None:
            self.subject = subject

    @property
    def acr(self):
        """Gets the acr of this ConsentRequest.  # noqa: E501

        ACR represents the Authentication AuthorizationContext Class Reference value for this authentication session. You can use it to express that, for example, a user authenticated using two factor authentication.  # noqa: E501

        :return: The acr of this ConsentRequest.  # noqa: E501
        :rtype: str
        """
        return self._acr

    @acr.setter
    def acr(self, acr):
        """Sets the acr of this ConsentRequest.

        ACR represents the Authentication AuthorizationContext Class Reference value for this authentication session. You can use it to express that, for example, a user authenticated using two factor authentication.  # noqa: E501

        :param acr: The acr of this ConsentRequest.  # noqa: E501
        :type: str
        """

        self._acr = acr

    @property
    def challenge(self):
        """Gets the challenge of this ConsentRequest.  # noqa: E501

        Challenge is the identifier (\"authorization challenge\") of the consent authorization request. It is used to identify the session.  # noqa: E501

        :return: The challenge of this ConsentRequest.  # noqa: E501
        :rtype: str
        """
        return self._challenge

    @challenge.setter
    def challenge(self, challenge):
        """Sets the challenge of this ConsentRequest.

        Challenge is the identifier (\"authorization challenge\") of the consent authorization request. It is used to identify the session.  # noqa: E501

        :param challenge: The challenge of this ConsentRequest.  # noqa: E501
        :type: str
        """

        self._challenge = challenge

    @property
    def client(self):
        """Gets the client of this ConsentRequest.  # noqa: E501


        :return: The client of this ConsentRequest.  # noqa: E501
        :rtype: OAuth2Client
        """
        return self._client

    @client.setter
    def client(self, client):
        """Sets the client of this ConsentRequest.


        :param client: The client of this ConsentRequest.  # noqa: E501
        :type: OAuth2Client
        """

        self._client = client

    @property
    def context(self):
        """Gets the context of this ConsentRequest.  # noqa: E501

        Context contains arbitrary information set by the login endpoint or is empty if not set.  # noqa: E501

        :return: The context of this ConsentRequest.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._context

    @context.setter
    def context(self, context):
        """Sets the context of this ConsentRequest.

        Context contains arbitrary information set by the login endpoint or is empty if not set.  # noqa: E501

        :param context: The context of this ConsentRequest.  # noqa: E501
        :type: dict(str, object)
        """

        self._context = context

    @property
    def login_challenge(self):
        """Gets the login_challenge of this ConsentRequest.  # noqa: E501

        LoginChallenge is the login challenge this consent challenge belongs to. It can be used to associate a login and consent request in the login & consent app.  # noqa: E501

        :return: The login_challenge of this ConsentRequest.  # noqa: E501
        :rtype: str
        """
        return self._login_challenge

    @login_challenge.setter
    def login_challenge(self, login_challenge):
        """Sets the login_challenge of this ConsentRequest.

        LoginChallenge is the login challenge this consent challenge belongs to. It can be used to associate a login and consent request in the login & consent app.  # noqa: E501

        :param login_challenge: The login_challenge of this ConsentRequest.  # noqa: E501
        :type: str
        """

        self._login_challenge = login_challenge

    @property
    def login_session_id(self):
        """Gets the login_session_id of this ConsentRequest.  # noqa: E501

        LoginSessionID is the login session ID. If the user-agent reuses a login session (via cookie / remember flag) this ID will remain the same. If the user-agent did not have an existing authentication session (e.g. remember is false) this will be a new random value. This value is used as the \"sid\" parameter in the ID Token and in OIDC Front-/Back- channel logout. It's value can generally be used to associate consecutive login requests by a certain user.  # noqa: E501

        :return: The login_session_id of this ConsentRequest.  # noqa: E501
        :rtype: str
        """
        return self._login_session_id

    @login_session_id.setter
    def login_session_id(self, login_session_id):
        """Sets the login_session_id of this ConsentRequest.

        LoginSessionID is the login session ID. If the user-agent reuses a login session (via cookie / remember flag) this ID will remain the same. If the user-agent did not have an existing authentication session (e.g. remember is false) this will be a new random value. This value is used as the \"sid\" parameter in the ID Token and in OIDC Front-/Back- channel logout. It's value can generally be used to associate consecutive login requests by a certain user.  # noqa: E501

        :param login_session_id: The login_session_id of this ConsentRequest.  # noqa: E501
        :type: str
        """

        self._login_session_id = login_session_id

    @property
    def oidc_context(self):
        """Gets the oidc_context of this ConsentRequest.  # noqa: E501


        :return: The oidc_context of this ConsentRequest.  # noqa: E501
        :rtype: OpenIDConnectContext
        """
        return self._oidc_context

    @oidc_context.setter
    def oidc_context(self, oidc_context):
        """Sets the oidc_context of this ConsentRequest.


        :param oidc_context: The oidc_context of this ConsentRequest.  # noqa: E501
        :type: OpenIDConnectContext
        """

        self._oidc_context = oidc_context

    @property
    def request_url(self):
        """Gets the request_url of this ConsentRequest.  # noqa: E501

        RequestURL is the original OAuth 2.0 Authorization URL requested by the OAuth 2.0 client. It is the URL which initiates the OAuth 2.0 Authorization Code or OAuth 2.0 Implicit flow. This URL is typically not needed, but might come in handy if you want to deal with additional request parameters.  # noqa: E501

        :return: The request_url of this ConsentRequest.  # noqa: E501
        :rtype: str
        """
        return self._request_url

    @request_url.setter
    def request_url(self, request_url):
        """Sets the request_url of this ConsentRequest.

        RequestURL is the original OAuth 2.0 Authorization URL requested by the OAuth 2.0 client. It is the URL which initiates the OAuth 2.0 Authorization Code or OAuth 2.0 Implicit flow. This URL is typically not needed, but might come in handy if you want to deal with additional request parameters.  # noqa: E501

        :param request_url: The request_url of this ConsentRequest.  # noqa: E501
        :type: str
        """

        self._request_url = request_url

    @property
    def requested_access_token_audience(self):
        """Gets the requested_access_token_audience of this ConsentRequest.  # noqa: E501

        RequestedScope contains the access token audience as requested by the OAuth 2.0 Client.  # noqa: E501

        :return: The requested_access_token_audience of this ConsentRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._requested_access_token_audience

    @requested_access_token_audience.setter
    def requested_access_token_audience(self, requested_access_token_audience):
        """Sets the requested_access_token_audience of this ConsentRequest.

        RequestedScope contains the access token audience as requested by the OAuth 2.0 Client.  # noqa: E501

        :param requested_access_token_audience: The requested_access_token_audience of this ConsentRequest.  # noqa: E501
        :type: list[str]
        """

        self._requested_access_token_audience = requested_access_token_audience

    @property
    def requested_scope(self):
        """Gets the requested_scope of this ConsentRequest.  # noqa: E501

        RequestedScope contains the OAuth 2.0 Scope requested by the OAuth 2.0 Client.  # noqa: E501

        :return: The requested_scope of this ConsentRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._requested_scope

    @requested_scope.setter
    def requested_scope(self, requested_scope):
        """Sets the requested_scope of this ConsentRequest.

        RequestedScope contains the OAuth 2.0 Scope requested by the OAuth 2.0 Client.  # noqa: E501

        :param requested_scope: The requested_scope of this ConsentRequest.  # noqa: E501
        :type: list[str]
        """

        self._requested_scope = requested_scope

    @property
    def skip(self):
        """Gets the skip of this ConsentRequest.  # noqa: E501

        Skip, if true, implies that the client has requested the same scopes from the same user previously. If true, you must not ask the user to grant the requested scopes. You must however either allow or deny the consent request using the usual API call.  # noqa: E501

        :return: The skip of this ConsentRequest.  # noqa: E501
        :rtype: bool
        """
        return self._skip

    @skip.setter
    def skip(self, skip):
        """Sets the skip of this ConsentRequest.

        Skip, if true, implies that the client has requested the same scopes from the same user previously. If true, you must not ask the user to grant the requested scopes. You must however either allow or deny the consent request using the usual API call.  # noqa: E501

        :param skip: The skip of this ConsentRequest.  # noqa: E501
        :type: bool
        """

        self._skip = skip

    @property
    def subject(self):
        """Gets the subject of this ConsentRequest.  # noqa: E501

        Subject is the user ID of the end-user that authenticated. Now, that end user needs to grant or deny the scope requested by the OAuth 2.0 client.  # noqa: E501

        :return: The subject of this ConsentRequest.  # noqa: E501
        :rtype: str
        """
        return self._subject

    @subject.setter
    def subject(self, subject):
        """Sets the subject of this ConsentRequest.

        Subject is the user ID of the end-user that authenticated. Now, that end user needs to grant or deny the scope requested by the OAuth 2.0 client.  # noqa: E501

        :param subject: The subject of this ConsentRequest.  # noqa: E501
        :type: str
        """

        self._subject = subject

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ConsentRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ConsentRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    ORY Hydra

    Welcome to the ORY Hydra HTTP API documentation. You will find documentation for all HTTP APIs here.  # noqa: E501

    The version of the OpenAPI document: v0.0.0-alpha.1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import ory_hydra_client
from ory_hydra_client.api.admin_api import AdminApi  # noqa: E501
from ory_hydra_client.rest import ApiException


class TestAdminApi(unittest.TestCase):
    """AdminApi unit test stubs"""

    def setUp(self):
        self.api = ory_hydra_client.api.admin_api.AdminApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_accept_consent_request(self):
        """Test case for accept_consent_request

        Accept an consent request  # noqa: E501
        """
        pass

    def test_accept_login_request(self):
        """Test case for accept_login_request

        Accept an login request  # noqa: E501
        """
        pass

    def test_accept_logout_request(self):
        """Test case for accept_logout_request

        Accept a logout request  # noqa: E501
        """
        pass

    def test_create_json_web_key_set(self):
        """Test case for create_json_web_key_set

        Generate a new JSON Web Key  # noqa: E501
        """
        pass

    def test_create_o_auth2_client(self):
        """Test case for create_o_auth2_client

        Create an OAuth 2.0 client  # noqa: E501
        """
        pass

    def test_delete_json_web_key(self):
        """Test case for delete_json_web_key

        Delete a JSON Web Key  # noqa: E501
        """
        pass

    def test_delete_json_web_key_set(self):
        """Test case for delete_json_web_key_set

        Delete a JSON Web Key Set  # noqa: E501
        """
        pass

    def test_delete_o_auth2_client(self):
        """Test case for delete_o_auth2_client

        Deletes an OAuth 2.0 Client  # noqa: E501
        """
        pass

    def test_flush_inactive_o_auth2_tokens(self):
        """Test case for flush_inactive_o_auth2_tokens

        Flush Expired OAuth2 Access Tokens  # noqa: E501
        """
        pass

    def test_get_consent_request(self):
        """Test case for get_consent_request

        Get consent request information  # noqa: E501
        """
        pass

    def test_get_json_web_key(self):
        """Test case for get_json_web_key

        Fetch a JSON Web Key  # noqa: E501
        """
        pass

    def test_get_json_web_key_set(self):
        """Test case for get_json_web_key_set

        Retrieve a JSON Web Key Set  # noqa: E501
        """
        pass

    def test_get_login_request(self):
        """Test case for get_login_request

        Get an login request  # noqa: E501
        """
        pass

    def test_get_logout_request(self):
        """Test case for get_logout_request

        Get a logout request  # noqa: E501
        """
        pass

    def test_get_o_auth2_client(self):
        """Test case for get_o_auth2_client

        Get an OAuth 2.0 Client.  # noqa: E501
        """
        pass

    def test_get_version(self):
        """Test case for get_version

        Get service version  # noqa: E501
        """
        pass

    def test_introspect_o_auth2_token(self):
        """Test case for introspect_o_auth2_token

        Introspect OAuth2 tokens  # noqa: E501
        """
        pass

    def test_is_instance_alive(self):
        """Test case for is_instance_alive

        Check alive status  # noqa: E501
        """
        pass

    def test_list_o_auth2_clients(self):
        """Test case for list_o_auth2_clients

        List OAuth 2.0 Clients  # noqa: E501
        """
        pass

    def test_list_subject_consent_sessions(self):
        """Test case for list_subject_consent_sessions

        Lists all consent sessions of a subject  # noqa: E501
        """
        pass

    def test_prometheus(self):
        """Test case for prometheus

        Get snapshot metrics from the Hydra service. If you're using k8s, you can then add annotations to your deployment like so:  # noqa: E501
        """
        pass

    def test_reject_consent_request(self):
        """Test case for reject_consent_request

        Reject an consent request  # noqa: E501
        """
        pass

    def test_reject_login_request(self):
        """Test case for reject_login_request

        Reject a login request  # noqa: E501
        """
        pass

    def test_reject_logout_request(self):
        """Test case for reject_logout_request

        Reject a logout request  # noqa: E501
        """
        pass

    def test_revoke_authentication_session(self):
        """Test case for revoke_authentication_session

        Invalidates all login sessions of a certain user Invalidates a subject's authentication session  # noqa: E501
        """
        pass

    def test_revoke_consent_sessions(self):
        """Test case for revoke_consent_sessions

        Revokes consent sessions of a subject for a specific OAuth 2.0 Client  # noqa: E501
        """
        pass

    def test_update_json_web_key(self):
        """Test case for update_json_web_key

        Update a JSON Web Key  # noqa: E501
        """
        pass

    def test_update_json_web_key_set(self):
        """Test case for update_json_web_key_set

        Update a JSON Web Key Set  # noqa: E501
        """
        pass

    def test_update_o_auth2_client(self):
        """Test case for update_o_auth2_client

        Update an OAuth 2.0 Client  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
